summaryrefslogtreecommitdiff
path: root/fpdfsdk/cpdfsdk_formfillenvironment.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'fpdfsdk/cpdfsdk_formfillenvironment.cpp')
-rw-r--r--fpdfsdk/cpdfsdk_formfillenvironment.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/fpdfsdk/cpdfsdk_formfillenvironment.cpp b/fpdfsdk/cpdfsdk_formfillenvironment.cpp
index 8f490ca2bc..568d89e96a 100644
--- a/fpdfsdk/cpdfsdk_formfillenvironment.cpp
+++ b/fpdfsdk/cpdfsdk_formfillenvironment.cpp
@@ -45,8 +45,8 @@ CPDFSDK_FormFillEnvironment::~CPDFSDK_FormFillEnvironment() {
m_bBeingDestroyed = true;
ClearAllFocusedAnnots();
// |m_PageMap| will try to access |m_pInterForm| when it cleans itself up.
// Make sure it is deleted before |m_pInterForm|.
m_PageMap.clear();
// |m_pAnnotHandlerMgr| will try to access |m_pFormFiller| when it cleans
@@ -623,10 +623,10 @@ IPDF_Page* CPDFSDK_FormFillEnvironment::GetPage(int nIndex) {
m_pInfo, FPDFDocumentFromCPDFDocument(m_pCPDFDoc.Get()), nIndex));
}
-CPDFSDK_InterForm* CPDFSDK_FormFillEnvironment::GetInterForm() {
- if (!m_pInterForm)
- m_pInterForm = pdfium::MakeUnique<CPDFSDK_InterForm>(this);
- return m_pInterForm.get();
+CPDFSDK_InteractiveForm* CPDFSDK_FormFillEnvironment::GetInteractiveForm() {
+ if (!m_pInteractiveForm)
+ m_pInteractiveForm = pdfium::MakeUnique<CPDFSDK_InteractiveForm>(this);
+ return m_pInteractiveForm.get();
}
void CPDFSDK_FormFillEnvironment::UpdateAllViews(CPDFSDK_PageView* pSender,
@@ -45,8 +45,8 @@ CPDFSDK_FormFillEnvironment::~CPDFSDK_FormFillEnvironment() {
m_bBeingDestroyed = true;
ClearAllFocusedAnnots();
- // |m_PageMap| will try to access |m_pInterForm| when it cleans itself up.
- // Make sure it is deleted before |m_pInterForm|.
+ // |m_PageMap| will try to access |m_pInteractiveForm| when it cleans itself
+ // up. Make sure it is deleted before |m_pInteractiveForm|.
m_PageMap.clear();
// |m_pAnnotHandlerMgr| will try to access |m_pFormFiller| when it cleans